@@ -318,7 +318,7 @@ int set_default_options(mod_gm_opt_t *opt) {
     }
     opt->exports_count = 0;
     opt->restrict_path_num      = 0;
-    opt->gearman_connection_timeout = 5000;
+    opt->gearman_connection_timeout = -1;
     for(i=0;i<GM_LISTSIZE;i++)
         opt->restrict_path[i] = NULL;
 
@@ -1025,8 +1025,6 @@ void dumpconfig(mod_gm_opt_t *opt, int mode) {
         gm_log( GM_LOG_DEBUG, "log mode:                        syslog (%d)\n", opt->logmode);
     if(opt->logmode == GM_LOG_MODE_TOOLS)
         gm_log( GM_LOG_DEBUG, "log mode:                        tools (%d)\n", opt->logmode);
-    if(opt->logmode == GM_LOG_MODE_CHECKS)
-        gm_log( GM_LOG_DEBUG, "log mode:            monitoring plugin (%d)\n", opt->logmode);
 
     if(mode == GM_WORKER_MODE) {
         gm_log( GM_LOG_DEBUG, "identifier:                      %s\n", opt->identifier);
@@ -1487,11 +1485,6 @@ void gm_log( int lvl, const char *text, ... ) {
     vsnprintf( buffer3, GM_BUFFERSIZE, text, ap );
     va_end( ap );
 
-    if ( debug_level >= GM_LOG_STDOUT || logmode == GM_LOG_MODE_CHECKS ) {
-        fprintf(stderr, "%s", buffer3 );
-        return;
-    }
-
     if ( debug_level >= GM_LOG_STDOUT || logmode == GM_LOG_MODE_TOOLS ) {
         printf( "%s", buffer3 );
         return;
@@ -1615,7 +1608,6 @@ void send_result_back(gm_job_t * exec_job) {
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
                          mod_gm_opt->transportmode,
-                         0,
                          0
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "send_result_back() finished successfully\n" );
@@ -1639,7 +1631,6 @@ void send_result_back(gm_job_t * exec_job) {
                               GM_JOB_PRIO_NORMAL,
                               GM_DEFAULT_JOB_RETRIES,
                               mod_gm_opt->transportmode,
-                              0,
                               0
                             ) == GM_OK) {
             gm_log( GM_LOG_TRACE, "send_result_back() finished successfully for duplicate server.\n" );
