@@ -259,7 +259,8 @@ int send_result() {
                          temp_buffer1,
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
-                         mod_gm_opt->transportmode
+                         mod_gm_opt->transportmode,
+                         0
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "send_result_back() finished successfully\n" );
 
@@ -271,7 +272,8 @@ int send_result() {
                                  temp_buffer1,
                                  GM_JOB_PRIO_NORMAL,
                                  GM_DEFAULT_JOB_RETRIES,
-                                 mod_gm_opt->transportmode
+                                 mod_gm_opt->transportmode,
+                                 0
                         ) == GM_OK) {
                 gm_log( GM_LOG_TRACE, "send_result_back() finished successfully for duplicate server.\n" );
             }
